Round corners — Thumbor 7.0.0a1 documentation

# Round corners

Usage: round_corner(a|b,r,g,b,[transparent])

## Description

This filter adds rounded corners to the image using the specified color as background.

## Arguments

- `a|b` - amount of pixels to use as radius. The argument `b` is not required, but it specifies the second value for the ellipsis used for the radius.

- `transparent` - Optional. If set to true/1, the background will be transparent.

## Examples

http://localhost:8888/unsafe/filters:round_corner(20,255,255,255)/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg

http://localhost:8888/unsafe/filters:round_corner(20|40,0,0,0)/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg

http://localhost:8888/unsafe/filters:round_corner(30,0,0,0,1)/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg